import { Ast, AstNode } from './ast';
import { IAstParser } from './parser';
export declare enum AbiItemType {
    FUNCTION = "function",
    EVENT = "event"
}
export declare enum FieldType {
    STRING = "string",
    ADDRESS = "address",
    UINT = "uint",
    UINT256 = "uint256",
    UINT64 = "uint64",
    BOOL = "bool",
    UINT8 = "uint8",
    INT8 = "int8"
}
export interface EventField {
    name: string;
    type: FieldType;
    indexed: boolean;
}
interface BaseItem {
    name: string;
    type: AbiItemType;
    inputs: any[];
}
export interface EventItem extends BaseItem {
    anonymous: boolean;
    inputs: EventField[];
}
export declare type StateMutability = 'pure' | 'view' | 'nonpayable' | 'payable';
export interface AbiItem extends BaseItem {
    constant: boolean;
    outputs: any[];
    payable: boolean;
    stateMutability: StateMutability;
}
export declare type ABI = (AbiItem | EventItem)[];
export interface BuiltContractData {
    contractName: string;
    abi: ABI;
    ast: Ast;
}
export declare class ContractInstance {
    private data;
    private _parser;
    constructor(data: BuiltContractData);
    get contractName(): string;
    get abi(): ABI;
    get ast(): Ast;
    get astParser(): IAstParser;
    listEvents(): EventItem[];
    listMethods(): AbiItem[];
    listAstMethods(): AstNode[];
}
export declare function loadContract(path: string): ContractInstance;
export {};
